public inbox for gentoo-commits@lists.gentoo.org
 help / color / mirror / Atom feed
* [gentoo-commits] gentoo-x86 commit in dev-util/cmake/files: cmake-2.6.0-interix.patch cmake-2.8.0-more-no_host_paths.patch cmake-2.6.3-fix_broken_lfs_on_aix.patch cmake-2.6.3-darwin-bundle.patch cmake-2.6.3-no-duplicates-in-rpath.patch
@ 2010-01-11  1:25 Jonathan Callen (abcd)
  0 siblings, 0 replies; only message in thread
From: Jonathan Callen (abcd) @ 2010-01-11  1:25 UTC (permalink / raw
  To: gentoo-commits

abcd        10/01/11 01:25:08

  Added:                cmake-2.6.0-interix.patch
                        cmake-2.8.0-more-no_host_paths.patch
                        cmake-2.6.3-fix_broken_lfs_on_aix.patch
                        cmake-2.6.3-darwin-bundle.patch
                        cmake-2.6.3-no-duplicates-in-rpath.patch
  Log:
  Add prefix keywords, patches
  (Portage version: -svn/cvs/Linux i686)

Revision  Changes    Path
1.1                  dev-util/cmake/files/cmake-2.6.0-interix.patch

file : http://sources.gentoo.org/viewcvs.py/gentoo-x86/dev-util/cmake/files/cmake-2.6.0-interix.patch?rev=1.1&view=markup
plain: http://sources.gentoo.org/viewcvs.py/gentoo-x86/dev-util/cmake/files/cmake-2.6.0-interix.patch?rev=1.1&content-type=text/plain

Index: cmake-2.6.0-interix.patch
===================================================================
diff -ruN cmake-2.6.0.orig/Modules/Platform/Interix.cmake cmake-2.6.0/Modules/Platform/Interix.cmake
--- cmake-2.6.0.orig/Modules/Platform/Interix.cmake	1970-01-01 01:00:00 +0100
+++ cmake-2.6.0/Modules/Platform/Interix.cmake	2008-06-02 14:22:45 +0200
@@ -0,0 +1,31 @@
+# This is a proposed Platform definition for Interix GCC/G++
+
+SET(CMAKE_DL_LIBS "dl")
+SET(CMAKE_SHARED_LIBRARY_C_FLAGS "")
+SET(CMAKE_SHARED_LIBRARY_CREATE_C_FLAGS "-shared")
+SET(CMAKE_SHARED_LIBRARY_LINK_C_FLAGS "")
+SET(CMAKE_SHARED_LIBRARY_RUNTIME_C_FLAG "-Wl,-rpath,")
+SET(CMAKE_SHARED_LIBRARY_RUNTIME_C_FLAG_SEP ":")
+SET(CMAKE_SHARED_LIBRARY_SONAME_C_FLAG "-Wl,-h,")
+SET(CMAKE_SHARED_LIBRARY_SONAME_CXX_FLAG "-Wl,-h,")
+
+SET(UNIX 1)
+
+# also add the install directory of the running cmake to the search directories
+# CMAKE_ROOT is CMAKE_INSTALL_PREFIX/share/cmake, so we need to go two levels up
+GET_FILENAME_COMPONENT(_CMAKE_INSTALL_DIR "${CMAKE_ROOT}" PATH)
+GET_FILENAME_COMPONENT(_CMAKE_INSTALL_DIR "${_CMAKE_INSTALL_DIR}" PATH)
+
+LIST(APPEND CMAKE_SYSTEM_PREFIX_PATH
+	"${_CMAKE_INSTALL_DIR}"
+	"${CMAKE_INSTALL_PREFIX}"
+	)
+
+LIST(APPEND CMAKE_SYSTEM_INCLUDE_PATH
+	"${CMAKE_INSTALL_PREFIX}"/include
+	)
+
+LIST(APPEND CMAKE_SYSTEM_LIBRARY_PATH
+	"${CMAKE_INSTALL_PREFIX}"/lib
+	)
+
diff -ruN cmake-2.6.0.orig/Utilities/cmtar/encode.c cmake-2.6.0/Utilities/cmtar/encode.c
--- cmake-2.6.0.orig/Utilities/cmtar/encode.c	2008-06-02 13:00:44 +0200
+++ cmake-2.6.0/Utilities/cmtar/encode.c	2008-06-02 14:02:39 +0200
@@ -24,6 +24,9 @@
 # include <stdlib.h>
 #endif
 
+#ifdef HAVE_SYS_MKDEV_H
+# include <sys/mkdev.h>
+#endif
 
 /* magic, version, and checksum */
 void



1.1                  dev-util/cmake/files/cmake-2.8.0-more-no_host_paths.patch

file : http://sources.gentoo.org/viewcvs.py/gentoo-x86/dev-util/cmake/files/cmake-2.8.0-more-no_host_paths.patch?rev=1.1&view=markup
plain: http://sources.gentoo.org/viewcvs.py/gentoo-x86/dev-util/cmake/files/cmake-2.8.0-more-no_host_paths.patch?rev=1.1&content-type=text/plain

--- cmake-2.8.0/Modules/Platform/UnixPaths.cmake
+++ cmake-2.8.0/Modules/Platform/UnixPaths.cmake
@@ -33,6 +33,7 @@
 # search types.
 LIST(APPEND CMAKE_SYSTEM_PREFIX_PATH
   # Standard
+  @GENTOO_PORTAGE_EPREFIX@usr/local @GENTOO_PORTAGE_EPREFIX@ @GENTOO_PORTAGE_EPREFIX@usr
   /usr/local / /usr
 
   # CMake install location
@@ -44,43 +45,39 @@
 
 # List common include file locations not under the common prefixes.
 LIST(APPEND CMAKE_SYSTEM_INCLUDE_PATH
-  # Windows API on Cygwin
-  /usr/include/w32api
-
-  # X11
-  /usr/X11R6/include /usr/include/X11
-
-  # Other
-  /opt/local/include /usr/pkg/include
-  /opt/csw/include /opt/include  
-  /usr/openwin/include
+  @GENTOO_PORTAGE_EPREFIX@usr/include
   )
 
 LIST(APPEND CMAKE_SYSTEM_LIBRARY_PATH
-  # Windows API on Cygwin
-  /usr/lib/w32api
-
-  # X11
-  /usr/X11R6/lib /usr/lib/X11
-
-  # Other
-  /opt/local/lib /usr/pkg/lib
-  /opt/csw/lib /opt/lib 
-  /usr/openwin/lib
+  @GENTOO_PORTAGE_GCCLIBDIR@/gcc
+  @GENTOO_PORTAGE_GCCLIBDIR@
+  @GENTOO_PORTAGE_EPREFIX@usr/lib64
+  @GENTOO_PORTAGE_EPREFIX@usr/lib32
+  @GENTOO_PORTAGE_EPREFIX@usr/lib
+  @GENTOO_PORTAGE_EPREFIX@lib
   )
 
 LIST(APPEND CMAKE_SYSTEM_PROGRAM_PATH
-  /usr/pkg/bin
+  @GENTOO_PORTAGE_EPREFIX@usr/bin
+  @GENTOO_PORTAGE_EPREFIX@bin
   )
 
 LIST(APPEND CMAKE_PLATFORM_IMPLICIT_LINK_DIRECTORIES
+  @GENTOO_PORTAGE_GCCLIBDIR@/gcc
+  @GENTOO_PORTAGE_GCCLIBDIR@
+  @GENTOO_PORTAGE_EPREFIX@usr/lib64
+  @GENTOO_PORTAGE_EPREFIX@usr/lib32
+  @GENTOO_PORTAGE_EPREFIX@usr/lib
+  @GENTOO_PORTAGE_EPREFIX@lib
   /lib /usr/lib /usr/lib32 /usr/lib64
   )
 
 LIST(APPEND CMAKE_C_IMPLICIT_INCLUDE_DIRECTORIES
+  @GENTOO_PORTAGE_EPREFIX@usr/include
   /usr/include
   )
 LIST(APPEND CMAKE_CXX_IMPLICIT_INCLUDE_DIRECTORIES
+  @GENTOO_PORTAGE_EPREFIX@usr/include
   /usr/include
   )
 



1.1                  dev-util/cmake/files/cmake-2.6.3-fix_broken_lfs_on_aix.patch

file : http://sources.gentoo.org/viewcvs.py/gentoo-x86/dev-util/cmake/files/cmake-2.6.3-fix_broken_lfs_on_aix.patch?rev=1.1&view=markup
plain: http://sources.gentoo.org/viewcvs.py/gentoo-x86/dev-util/cmake/files/cmake-2.6.3-fix_broken_lfs_on_aix.patch?rev=1.1&content-type=text/plain

Index: cmake-2.6.3-fix_broken_lfs_on_aix.patch
===================================================================
http://public.kitware.com/Bug/view.php?id=7933

diff -ur cmake-2.6.2/Source/kwsys/kwsysPlatformTestsCXX.cxx cmake-2.6.2-p/Source/kwsys/kwsysPlatformTestsCXX.cxx
--- cmake-2.6.2/Source/kwsys/kwsysPlatformTestsCXX.cxx	Wed Sep 24 20:34:37 2008
+++ cmake-2.6.2-p/Source/kwsys/kwsysPlatformTestsCXX.cxx	Tue Nov  4 11:18:32 2008
@@ -38,6 +38,13 @@
 int main() { return 0; }
 #endif
 
+#ifdef TEST_KWSYS_LFS_SUPPORT
+#define _LARGE_FILES
+#include <iostream>
+int main() { return 0; }
+#endif
+
+
 #ifdef TEST_KWSYS_IOS_HAVE_STD
 #include <iosfwd>
 void f(std ::ostream*) {}
diff -ur cmake-2.6.2/bootstrap cmake-2.6.2-p/bootstrap
--- cmake-2.6.2/bootstrap	Wed Sep 24 20:34:33 2008
+++ cmake-2.6.2-p/bootstrap	Tue Nov  4 11:17:11 2008
@@ -1005,6 +1005,16 @@
   echo "${cmake_cxx_compiler} does not have stl iterator_traits"
 fi
 
+if cmake_try_run "${cmake_cxx_compiler}" \
+  "${cmake_cxx_flags} -DTEST_KWSYS_LFS_SUPPORT" \
+  "${cmake_source_dir}/Source/kwsys/kwsysPlatformTestsCXX.cxx" >> cmake_bootstrap.log 2>&1; then
+  KWSYS_LFS_AVAILABLE=1
+  echo "LFS support available"
+else
+  KWSYS_LFS_AVAILABLE=0
+  echo "LFS support unavailable, disabled"
+fi
+
 if [ "x${KWSYS_STL_HAS_ITERATOR_TRAITS}" = "x0" ]; then
   if cmake_try_run "${cmake_cxx_compiler}" \
     "${cmake_cxx_flags} -DTEST_KWSYS_STL_HAS_ITERATOR_CATEGORY -DKWSYS_STL_HAVE_STD=${KWSYS_STL_HAVE_STD}" \



1.1                  dev-util/cmake/files/cmake-2.6.3-darwin-bundle.patch

file : http://sources.gentoo.org/viewcvs.py/gentoo-x86/dev-util/cmake/files/cmake-2.6.3-darwin-bundle.patch?rev=1.1&view=markup
plain: http://sources.gentoo.org/viewcvs.py/gentoo-x86/dev-util/cmake/files/cmake-2.6.3-darwin-bundle.patch?rev=1.1&content-type=text/plain

Index: cmake-2.6.3-darwin-bundle.patch
===================================================================
Don't use .so for modules on darwin/macos. Use .bundle instead.
Patch by Heiko Przybyl

--- Modules/Platform/Darwin.cmake
+++ Modules/Platform/Darwin.cmake
@@ -23,7 +23,7 @@
 SET(CMAKE_SHARED_LIBRARY_PREFIX "lib")
 SET(CMAKE_SHARED_LIBRARY_SUFFIX ".dylib")
 SET(CMAKE_SHARED_MODULE_PREFIX "lib")
-SET(CMAKE_SHARED_MODULE_SUFFIX ".so")
+SET(CMAKE_SHARED_MODULE_SUFFIX ".bundle")
 SET(CMAKE_MODULE_EXISTS 1)
 SET(CMAKE_DL_LIBS "")
 
@@ -45,7 +45,7 @@
 SET(CMAKE_SHARED_MODULE_CREATE_C_FLAGS "-bundle -headerpad_max_install_names")
 SET(CMAKE_SHARED_MODULE_LOADER_C_FLAG "-Wl,-bundle_loader,")
 SET(CMAKE_SHARED_MODULE_LOADER_CXX_FLAG "-Wl,-bundle_loader,")
-SET(CMAKE_FIND_LIBRARY_SUFFIXES ".dylib" ".so" ".a")
+SET(CMAKE_FIND_LIBRARY_SUFFIXES ".dylib" ".bundle" ".a")
 
 # hack: if a new cmake (which uses CMAKE_INSTALL_NAME_TOOL) runs on an old build tree
 # (where install_name_tool was hardcoded) and where CMAKE_INSTALL_NAME_TOOL isn't in the cache



1.1                  dev-util/cmake/files/cmake-2.6.3-no-duplicates-in-rpath.patch

file : http://sources.gentoo.org/viewcvs.py/gentoo-x86/dev-util/cmake/files/cmake-2.6.3-no-duplicates-in-rpath.patch?rev=1.1&view=markup
plain: http://sources.gentoo.org/viewcvs.py/gentoo-x86/dev-util/cmake/files/cmake-2.6.3-no-duplicates-in-rpath.patch?rev=1.1&content-type=text/plain

Index: cmake-2.6.3-no-duplicates-in-rpath.patch
===================================================================
Patch by Heiko Przybyl

--- Source/cmComputeLinkInformation.cxx
+++ Source/cmComputeLinkInformation.cxx
@@ -1686,6 +1686,14 @@ std::string cmComputeLinkInformation::Ge
   for(std::vector<std::string>::const_iterator ri = runtimeDirs.begin();
       ri != runtimeDirs.end(); ++ri)
     {
+      // Do not add duplicates.
+      // I'd like to have that check already in the list generation code
+      // but that would need lots of more changes, even in ExpandListArgument().
+      if(*sep != '\0' && (rpath + sep).find(*ri + sep) != std::string::npos)
+        {
+          //std::cerr << "ignoring duplicate: '" << *ri << "' in '" << rpath << "'" << std::endl;
+          continue;
+        }
     // Separate from previous path.
     rpath += sep;
     sep = this->GetRuntimeSep().c_str();






^ permalink raw reply	[flat|nested] only message in thread

only message in thread, other threads:[~2010-01-11  1:25 UTC | newest]

Thread overview: (only message) (download: mbox.gz follow: Atom feed
-- links below jump to the message on this page --
2010-01-11  1:25 [gentoo-commits] gentoo-x86 commit in dev-util/cmake/files: cmake-2.6.0-interix.patch cmake-2.8.0-more-no_host_paths.patch cmake-2.6.3-fix_broken_lfs_on_aix.patch cmake-2.6.3-darwin-bundle.patch cmake-2.6.3-no-duplicates-in-rpath.patch Jonathan Callen (abcd)

This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox
Index: cmake-2.8.0-more-no_host_paths.patch
===================================================================
Set some proper paths to make cmake find our tools.
Original patch by Heiko Przybyl

The ebuild now adds an extra / at the end of $EPREFIX so that it is
never the empty string (so that CMAKE_SYSTEM_PREFIX_PATH remains
correct)

--- cmake-2.8.0/Modules/Platform/Darwin.cmake
+++ cmake-2.8.0/Modules/Platform/Darwin.cmake
@@ -213,19 +213,23 @@
 
 
  
-# default to searching for frameworks first
-SET(CMAKE_FIND_FRAMEWORK FIRST)
+# default to searching for frameworks last
+SET(CMAKE_FIND_FRAMEWORK LAST)
 # set up the default search directories for frameworks
 SET(CMAKE_SYSTEM_FRAMEWORK_PATH
+  @GENTOO_PORTAGE_EPREFIX@Frameworks
+  @GENTOO_PORTAGE_EPREFIX@usr/lib
   ~/Library/Frameworks
   /Library/Frameworks
   /Network/Library/Frameworks
   /System/Library/Frameworks)
 
-# default to searching for application bundles first
-SET(CMAKE_FIND_APPBUNDLE FIRST)
+# default to searching for application bundles last
+SET(CMAKE_FIND_APPBUNDLE LAST)
 # set up the default search directories for application bundles
 SET(CMAKE_SYSTEM_APPBUNDLE_PATH
+  @GENTOO_PORTAGE_EPREFIX@Applications
+  @GENTOO_PORTAGE_EPREFIX@usr/bin
   ~/Applications
   /Applications
   /Developer/Applications)